==> lms-1.1.2b.tar.gz: lms/modules/print.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: print.php,v 1.16 2003/08/24 13:12:54 lukasz Exp $
 */

$layout[pagetitle]="Wydruki";
$SMARTY->assign("layout",$layout);

$su = $ADB->GetOne("SELECT min(time) FROM cash");
$eu = $ADB->GetOne("SELECT max(time) FROM cash");
$sm = date("m",$su);
$sy = date("Y",$su);
$em = date("m",$eu);
$ey = date("Y",$eu);

for($d=$sy;$d<$ey+1;$d++)
{
//	echo "<B>$d</B><BR>";
	if($d==$sy)
		$smm = $sm;
	else
		$smm = 1;
	if($d==$ey)
		$emm = $em;
	else
		$emm = 12;
//	echo "<B>$smm-$emm</B><BR>";
	for($m=$smm;$m<$emm+1;$m++)
		$monthlist[] = "$d/$m";
}

$SMARTY->assign("monthlist",$monthlist);

switch($_GET[type])
{
	case "userlist":
		$SMARTY->assign("userlist",$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
		$SMARTY->display("printuserlist.html");
	break;

	case "nodelist":
		$SMARTY->assign("nodelist",$LMS->GetNodeList($_SESSION['nlo']));
		$SMARTY->display("printnodelist.html");
	break;
	
	case "userlistminus":
		$SMARTY->assign("userlist",$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
		$SMARTY->display("printuserlistminus.html");
	break;

	default:
		$SMARTY->display("printindex.html");
	break;
}
/*
 * $Log: print.php,v $
 * Revision 1.16  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.15  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>

==> lms-1.1.5.tar.gz: lms/modules/print.php <==
<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: print.php,v 1.17 2003/09/05 18:51:58 alec Exp $
 */

$layout[pagetitle]="Wydruki";
$SMARTY->assign("layout",$layout);

$su = $DB->GetOne("SELECT min(time) FROM cash");
$eu = $DB->GetOne("SELECT max(time) FROM cash");
$sm = date("m",$su);
$sy = date("Y",$su);
$em = date("m",$eu);
$ey = date("Y",$eu);

for($d=$sy;$d<$ey+1;$d++)
{
//	echo "<B>$d</B><BR>";
	if($d==$sy)
		$smm = $sm;
	else
		$smm = 1;
	if($d==$ey)
		$emm = $em;
	else
		$emm = 12;
//	echo "<B>$smm-$emm</B><BR>";
	for($m=$smm;$m<$emm+1;$m++)
		$monthlist[] = "$d/$m";
}

$SMARTY->assign("monthlist",$monthlist);

switch($_GET[type])
{
	case "userlist":
		$SMARTY->assign("userlist",$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
		$SMARTY->display("printuserlist.html");
	break;

	case "nodelist":
		$SMARTY->assign("nodelist",$LMS->GetNodeList($_SESSION['nlo']));
		$SMARTY->display("printnodelist.html");
	break;
	
	case "userlistminus":
		$SMARTY->assign("userlist",$LMS->GetUserList($_SESSION['ulo'],$_SESSION['uls']));
		$SMARTY->display("printuserlistminus.html");
	break;

	default:
		$SMARTY->display("printindex.html");
	break;
}
/*
 * $Log: print.php,v $
 * Revision 1.17  2003/09/05 18:51:58  alec
 * ADB -> DB
 *
 * Revision 1.16  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.15  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>
